pub struct Trap { /* private fields */ }Expand description
A struct representing an aborted instruction execution, with a message indicating the cause.
Implementations
Sourceimpl Trap
impl Trap
Sourcepub fn new<I: Into<String>>(message: I) -> Self
pub fn new<I: Into<String>>(message: I) -> Self
Creates a new Trap with message.
Example
let trap = wasmtime::Trap::new("unexpected error");
assert!(trap.to_string().contains("unexpected error"));Sourcepub fn i32_exit(status: i32) -> Self
pub fn i32_exit(status: i32) -> Self
Creates a new Trap representing an explicit program exit with a classic i32
exit status value.
Sourcepub fn i32_exit_status(&self) -> Option<i32>
pub fn i32_exit_status(&self) -> Option<i32>
If the trap was the result of an explicit program exit with a classic
i32 exit status value, return the value, otherwise return None.